@@ -16,12 +16,14 @@ from E5Gui.E5Application import e5App
 from E5Gui.E5Action import E5Action
 from E5Gui import E5MessageBox
 
+import UI.Info
+
 # Start-Of-Header
 name = "Python re Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "6.2.0"
+version = UI.Info.VersionOnly
 className = "PyRegExpWizard"
 packageName = "__core__"
 shortDescription = "Show the Python re wizard."
