@@ -1037,18 +1037,21 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         if self.project.getProjectType() in ["Qt4", "Qt4C"]:
             self.pylupdate = 'pylupdate4'
             if Utilities.isWindowsPlatform():
-                self.pylupdate = self.pylupdate + '.exe'
+                self.pylupdate = \
+                    Utilities.getWindowsExecutablePath(self.pylupdate)
         elif self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
             self.pylupdate = 'pylupdate5'
             if Utilities.isWindowsPlatform():
-                self.pylupdate = self.pylupdate + '.exe'
+                self.pylupdate = \
+                    Utilities.getWindowsExecutablePath(self.pylupdate)
         elif self.project.getProjectType() in ["E6Plugin"]:
             if PYQT_VERSION < 0x050000:
                 self.pylupdate = 'pylupdate4'
             else:
                 self.pylupdate = 'pylupdate5'
             if Utilities.isWindowsPlatform():
-                self.pylupdate = self.pylupdate + '.exe'
+                self.pylupdate = \
+                    Utilities.getWindowsExecutablePath(self.pylupdate)
         elif self.project.getProjectType() in ["PySide", "PySideC"]:
             self.pylupdate = Utilities.generatePySideToolPath('pyside-lupdate')
         else:
